@@ -75,8 +75,9 @@ fontMap::fontMap()
         QString line;
         while (!stream.atEnd()) {
             line = stream.readLine().simplified();
-            if (line.isEmpty() || (line.at(0) == QLatin1Char('%')))
+            if (line.isEmpty() || (line.at(0) == QLatin1Char('%'))) {
                 continue;
+            }
 
             QString TeXName = line.section(QLatin1Char(' '), 0, 0);
             QString FullName = line.section(QLatin1Char(' '), 1, 1);
@@ -84,16 +85,18 @@ fontMap::fontMap()
             QString encodingName = line.section(QLatin1Char('<'), -2, -2).trimmed().section(QLatin1Char(' '), 0, 0);
             // It seems that sometimes the encoding is prepended by the
             // letter '[', which we ignore
-            if ((!encodingName.isEmpty()) && (encodingName[0] == QLatin1Char('[')))
+            if ((!encodingName.isEmpty()) && (encodingName[0] == QLatin1Char('['))) {
                 encodingName = encodingName.mid(1);
+            }
 
             double slant = 0.0;
             int i = line.indexOf(QStringLiteral("SlantFont"));
             if (i >= 0) {
                 bool ok;
                 slant = line.left(i).section(QLatin1Char(' '), -1, -1, QString::SectionSkipEmpty).toDouble(&ok);
-                if (ok == false)
+                if (ok == false) {
                     slant = 0.0;
+                }
             }
 
             fontMapEntry &entry = fontMapEntries[TeXName];
@@ -101,14 +104,16 @@ fontMap::fontMap()
             entry.slant = slant;
             entry.fontFileName = fontFileName;
             entry.fullFontName = FullName;
-            if (encodingName.endsWith(QLatin1String(".enc")))
+            if (encodingName.endsWith(QLatin1String(".enc"))) {
                 entry.fontEncoding = encodingName;
-            else
+            } else {
                 entry.fontEncoding.clear();
+            }
         }
         file.close();
-    } else
+    } else {
         qCCritical(OkularDviDebug) << QStringLiteral("fontMap::fontMap(): The file '%1' could not be opened.").arg(map_fileName) << endl;
+    }
 
 #ifdef DEBUG_FONTMAP
     qCDebug(OkularDviDebug) << "FontMap file parsed. Results:";
@@ -123,8 +128,9 @@ const QString &fontMap::findFileName(const QString &TeXName)
 {
     QMap<QString, fontMapEntry>::Iterator it = fontMapEntries.find(TeXName);
 
-    if (it != fontMapEntries.end())
+    if (it != fontMapEntries.end()) {
         return it.value().fontFileName;
+    }
 
     static const QString nullstring;
     return nullstring;
@@ -134,8 +140,9 @@ const QString &fontMap::findFontName(const QString &TeXName)
 {
     QMap<QString, fontMapEntry>::Iterator it = fontMapEntries.find(TeXName);
 
-    if (it != fontMapEntries.end())
+    if (it != fontMapEntries.end()) {
         return it.value().fullFontName;
+    }
 
     static const QString nullstring;
     return nullstring;
@@ -145,8 +152,9 @@ const QString &fontMap::findEncoding(const QString &TeXName)
 {
     QMap<QString, fontMapEntry>::Iterator it = fontMapEntries.find(TeXName);
 
-    if (it != fontMapEntries.end())
+    if (it != fontMapEntries.end()) {
         return it.value().fontEncoding;
+    }
 
     static const QString nullstring;
     return nullstring;
@@ -156,10 +164,11 @@ double fontMap::findSlant(const QString &TeXName)
 {
     QMap<QString, fontMapEntry>::Iterator it = fontMapEntries.find(TeXName);
 
-    if (it != fontMapEntries.end())
+    if (it != fontMapEntries.end()) {
         return it.value().slant;
-    else
+    } else {
         return 0.0;
+    }
 }
 
 #endif // HAVE_FREETYPE
